@@ -9,10 +9,7 @@ struct SPVM_constant {
   SPVM_TYPE* type;
   SPVM_VALUE value;
   int32_t string_length;
-  int32_t id;
-  int32_t info_long_constant_id;
-  int32_t info_double_constant_id;
-  int32_t info_string_constant_id;
+  int32_t constant_pool_id;
 };
 
 SPVM_CONSTANT* SPVM_CONSTANT_new(SPVM_COMPILER* compiler);
