@@ -152,7 +152,7 @@ enum {
   SPVM_OP_C_ID_BOOL,
   SPVM_OP_C_ID_LOOP_INCREMENT,
   SPVM_OP_C_ID_SELF,
-  SPVM_OP_C_ID_CHECK_CAST,
+  SPVM_OP_C_ID_CHECK_CONVERT,
   SPVM_OP_C_ID_STRING_EQ,
   SPVM_OP_C_ID_STRING_NE,
   SPVM_OP_C_ID_STRING_GT,
