@@ -452,11 +452,8 @@ enum {
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR_UNDEF,
   SPVM_OPCODE_C_ID_WEAKEN_FIELD,
-  SPVM_OPCODE_C_ID_WEAKEN_ARRAY_ELEMENT,
   SPVM_OPCODE_C_ID_UNWEAKEN_FIELD,
-  SPVM_OPCODE_C_ID_UNWEAKEN_ARRAY_ELEMENT,
   SPVM_OPCODE_C_ID_ISWEAK_FIELD,
-  SPVM_OPCODE_C_ID_ISWEAK_ARRAY_ELEMENT,
   SPVM_OPCODE_C_ID_END_SUB,
 };
 
