@@ -18,12 +18,14 @@ const char* const SPVM_BASIC_TYPE_C_ID_NAMES[] = {
   "double",
   "string",
   "object",
+  "oarray",
   "SPVM::Byte",
   "SPVM::Short",
   "SPVM::Int",
   "SPVM::Long",
   "SPVM::Float",
   "SPVM::Double",
+  "CORE",
 };
 
 SPVM_BASIC_TYPE* SPVM_BASIC_TYPE_new(SPVM_COMPILER* compiler) {
