@@ -452,11 +452,8 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "SET_EXCEPTION_VAR",
   "SET_EXCEPTION_UNDEF",
   "WEAKEN_FIELD",
-  "WEAKEN_ARRAY_ELEMENT",
   "UNWEAKEN_FIELD",
-  "UNWEAKEN_ARRAY_ELEMENT",
   "ISWEAK_FIELD",
-  "ISWEAK_ARRAY_ELEMENT",
   "END_SUB",
 };
 
